Learn R Programming

MCOE (version 0.6.0)

mcoe_name: Given a CDS code, it gives the name of the district

Description

Given a CDS code, it gives the name of the district

Usage

mcoe_name(cds.number)

Value

a `string` of the district name

Arguments

cds.number

County-District-School code from California Department of Education

Examples

Run this code
mcoe_name("27661590000000")

Run the code above in your browser using DataLab